"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TargetingEndAge(str, Enum):
    SEVENTEEN = "Seventeen"
    TWENTY = "Twenty"
    TWENTY_FOUR = "TwentyFour"
    TWENTY_NINE = "TwentyNine"
    THIRTY_FOUR = "ThirtyFour"
    THIRTY_NINE = "ThirtyNine"
    FORTY_FOUR = "FortyFour"
    FORTY_NINE = "FortyNine"
    FIFTY_FOUR = "FiftyFour"
    SIXTY_FOUR = "SixtyFour"
    SIXTY_FOUR_PLUS = "SixtyFourPlus"
