"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SubmitRestRequestResponseBodyTypedDict(TypedDict):
    r"""OK"""


class SubmitRestRequestResponseBody(BaseModel):
    r"""OK"""


class SubmitRestRequestResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[SubmitRestRequestResponseBodyTypedDict]
    r"""OK"""


class SubmitRestRequestResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[SubmitRestRequestResponseBody] = None
    r"""OK"""
