"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .standardjobsubmitresponse import (
    StandardJobSubmitResponse,
    StandardJobSubmitResponseTypedDict,
)
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateCampaignsJobResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    standard_job_submit_response: NotRequired[StandardJobSubmitResponseTypedDict]
    r"""Accepted"""


class CreateCampaignsJobResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    standard_job_submit_response: Optional[StandardJobSubmitResponse] = None
    r"""Accepted"""
