"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CampaignPacingMode(str, Enum):
    PACE_AHEAD = "PaceAhead"
    PACE_EVENLY = "PaceEvenly"
    PACE_TO_DAILY_CAP = "PaceToDailyCap"
    PACE_AS_SOON_AS_POSSIBLE = "PaceAsSoonAsPossible"
