"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .graphqlqueryjobresponse import (
    GraphQlQueryJobResponse,
    GraphQlQueryJobResponseTypedDict,
)
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SubmitGraphQlQueryJobResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    graph_ql_query_job_response: NotRequired[GraphQlQueryJobResponseTypedDict]
    r"""OK"""


class SubmitGraphQlQueryJobResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    graph_ql_query_job_response: Optional[GraphQlQueryJobResponse] = None
    r"""OK"""
