"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AllocationType(str, Enum):
    MINIMUM = "Minimum"
    FIXED = "Fixed"
    MAXIMUM = "Maximum"
