"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AdGroupKoaOptimizationSettingsTypedDict(TypedDict):
    are_future_koa_features_enabled: NotRequired[bool]
    predictive_clearing_enabled: NotRequired[bool]


class AdGroupKoaOptimizationSettings(BaseModel):
    are_future_koa_features_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="areFutureKoaFeaturesEnabled")
    ] = None

    predictive_clearing_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="predictiveClearingEnabled")
    ] = None
