"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AdGroupFunnelLocation(str, Enum):
    NONE = "None"
    AWARENESS = "Awareness"
    CONSIDERATION = "Consideration"
    CONVERSION = "Conversion"
