"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .adgroupassociatebidlist import (
        AdGroupAssociateBidList,
        AdGroupAssociateBidListTypedDict,
    )
    from .adgroupaudiencetargeting import (
        AdGroupAudienceTargeting,
        AdGroupAudienceTargetingTypedDict,
    )
    from .adgroupbudget import AdGroupBudget, AdGroupBudgetTypedDict
    from .adgroupbulkcreateworkflowinputwithvalidation import (
        AdGroupBulkCreateWorkflowInputWithValidation,
        AdGroupBulkCreateWorkflowInputWithValidationTypedDict,
    )
    from .adgroupbulkupdateworkflowinputwithvalidation import (
        AdGroupBulkUpdateWorkflowInputWithValidation,
        AdGroupBulkUpdateWorkflowInputWithValidationTypedDict,
    )
    from .adgroupchannel import AdGroupChannel
    from .adgroupcomscoresettings import (
        AdGroupComscoreSettings,
        AdGroupComscoreSettingsTypedDict,
    )
    from .adgroupcontracttargeting import (
        AdGroupContractTargeting,
        AdGroupContractTargetingTypedDict,
    )
    from .adgroupcreateworkflowinput import (
        AdGroupCreateWorkflowInput,
        AdGroupCreateWorkflowInputTypedDict,
    )
    from .adgroupcreateworkflowinputwithvalidation import (
        AdGroupCreateWorkflowInputWithValidation,
        AdGroupCreateWorkflowInputWithValidationTypedDict,
    )
    from .adgroupcreateworkflowprimaryinput import (
        AdGroupCreateWorkflowPrimaryInput,
        AdGroupCreateWorkflowPrimaryInputTypedDict,
    )
    from .adgroupflight import AdGroupFlight, AdGroupFlightTypedDict
    from .adgroupfunnellocation import AdGroupFunnelLocation
    from .adgroupkoaoptimizationsettings import (
        AdGroupKoaOptimizationSettings,
        AdGroupKoaOptimizationSettingsTypedDict,
    )
    from .adgroupnielsentrackingattributes import (
        AdGroupNielsenTrackingAttributes,
        AdGroupNielsenTrackingAttributesTypedDict,
    )
    from .adgrouppayload import AdGroupPayload, AdGroupPayloadTypedDict
    from .adgrouproigoal import AdGroupROIGoal, AdGroupROIGoalTypedDict
    from .adgroupupdateworkflowinput import (
        AdGroupUpdateWorkflowInput,
        AdGroupUpdateWorkflowInputTypedDict,
    )
    from .adgroupupdateworkflowinputwithvalidation import (
        AdGroupUpdateWorkflowInputWithValidation,
        AdGroupUpdateWorkflowInputWithValidationTypedDict,
    )
    from .adgroupupdateworkflowprimaryinput import (
        AdGroupUpdateWorkflowPrimaryInput,
        AdGroupUpdateWorkflowPrimaryInputTypedDict,
    )
    from .adgroupworkflow import AdGroupWorkflow, AdGroupWorkflowTypedDict
    from .adgroupworkflowadvancedinput import (
        AdGroupWorkflowAdvancedInput,
        AdGroupWorkflowAdvancedInputTypedDict,
    )
    from .adgroupworkflowassociatebidlistinput import (
        AdGroupWorkflowAssociateBidListInput,
        AdGroupWorkflowAssociateBidListInputTypedDict,
    )
    from .adgroupworkflowaudiencetargetinginput import (
        AdGroupWorkflowAudienceTargetingInput,
        AdGroupWorkflowAudienceTargetingInputTypedDict,
    )
    from .adgroupworkflowbudgetinput import (
        AdGroupWorkflowBudgetInput,
        AdGroupWorkflowBudgetInputTypedDict,
    )
    from .adgroupworkflowcomscoresettingsinput import (
        AdGroupWorkflowComscoreSettingsInput,
        AdGroupWorkflowComscoreSettingsInputTypedDict,
    )
    from .adgroupworkflowcontracttargetinginput import (
        AdGroupWorkflowContractTargetingInput,
        AdGroupWorkflowContractTargetingInputTypedDict,
    )
    from .adgroupworkflowflightinput import (
        AdGroupWorkflowFlightInput,
        AdGroupWorkflowFlightInputTypedDict,
    )
    from .adgroupworkflowkoaoptimizationsettingsinput import (
        AdGroupWorkflowKoaOptimizationSettingsInput,
        AdGroupWorkflowKoaOptimizationSettingsInputTypedDict,
    )
    from .adgroupworkflownewfrequencyconfiginput import (
        AdGroupWorkflowNewFrequencyConfigInput,
        AdGroupWorkflowNewFrequencyConfigInputTypedDict,
    )
    from .adgroupworkflownielsentrackingattributesinput import (
        AdGroupWorkflowNielsenTrackingAttributesInput,
        AdGroupWorkflowNielsenTrackingAttributesInputTypedDict,
    )
    from .adgroupworkflowroigoalinput import (
        AdGroupWorkflowROIGoalInput,
        AdGroupWorkflowROIGoalInputTypedDict,
    )
    from .allocationtype import AllocationType
    from .apierror import APIError
    from .archiveadgroupsop import (
        ArchiveAdGroupsRequest,
        ArchiveAdGroupsRequestTypedDict,
        ArchiveAdGroupsResponse,
        ArchiveAdGroupsResponseTypedDict,
    )
    from .archivecampaignsop import (
        ArchiveCampaignsRequest,
        ArchiveCampaignsRequestTypedDict,
        ArchiveCampaignsResponse,
        ArchiveCampaignsResponseTypedDict,
    )
    from .bulkjobstatus import BulkJobStatus
    from .callrestapiworkflowinput import (
        CallRestAPIWorkflowInput,
        CallRestAPIWorkflowInputTypedDict,
    )
    from .campaignbulkcreateworkflowinputwithvalidation import (
        CampaignBulkCreateWorkflowInputWithValidation,
        CampaignBulkCreateWorkflowInputWithValidationTypedDict,
    )
    from .campaignbulkupdateworkflowinputwithvalidation import (
        CampaignBulkUpdateWorkflowInputWithValidation,
        CampaignBulkUpdateWorkflowInputWithValidationTypedDict,
    )
    from .campaignchanneltype import CampaignChannelType
    from .campaigncreateworkflowadgroupadvancedinput import (
        CampaignCreateWorkflowAdGroupAdvancedInput,
        CampaignCreateWorkflowAdGroupAdvancedInputTypedDict,
    )
    from .campaigncreateworkflowadgroupflightinput import (
        CampaignCreateWorkflowAdGroupFlightInput,
        CampaignCreateWorkflowAdGroupFlightInputTypedDict,
    )
    from .campaigncreateworkflowadgroupinput import (
        CampaignCreateWorkflowAdGroupInput,
        CampaignCreateWorkflowAdGroupInputTypedDict,
    )
    from .campaigncreateworkflowinput import (
        CampaignCreateWorkflowInput,
        CampaignCreateWorkflowInputTypedDict,
    )
    from .campaigncreateworkflowinputwithvalidation import (
        CampaignCreateWorkflowInputWithValidation,
        CampaignCreateWorkflowInputWithValidationTypedDict,
    )
    from .campaigncreateworkflowprimaryinput import (
        CampaignCreateWorkflowPrimaryInput,
        CampaignCreateWorkflowPrimaryInputTypedDict,
    )
    from .campaignflightworkflow import (
        CampaignFlightWorkflow,
        CampaignFlightWorkflowTypedDict,
    )
    from .campaignpacingmode import CampaignPacingMode
    from .campaignpayload import CampaignPayload, CampaignPayloadTypedDict
    from .campaignupdateworkflowinput import (
        CampaignUpdateWorkflowInput,
        CampaignUpdateWorkflowInputTypedDict,
    )
    from .campaignupdateworkflowinputwithvalidation import (
        CampaignUpdateWorkflowInputWithValidation,
        CampaignUpdateWorkflowInputWithValidationTypedDict,
    )
    from .campaignupdateworkflowprimaryinput import (
        CampaignUpdateWorkflowPrimaryInput,
        CampaignUpdateWorkflowPrimaryInputTypedDict,
    )
    from .campaignversionworkflow import (
        CampaignVersionWorkflow,
        CampaignVersionWorkflowTypedDict,
    )
    from .campaignworkflow import CampaignWorkflow, CampaignWorkflowTypedDict
    from .campaignworkflowadvancedinput import (
        CampaignWorkflowAdvancedInput,
        CampaignWorkflowAdvancedInputTypedDict,
    )
    from .campaignworkflowbudgetinput import (
        CampaignWorkflowBudgetInput,
        CampaignWorkflowBudgetInputTypedDict,
    )
    from .campaignworkflowcampaignconversionreportingcolumninput import (
        CampaignWorkflowCampaignConversionReportingColumnInput,
        CampaignWorkflowCampaignConversionReportingColumnInputTypedDict,
    )
    from .campaignworkflowflightinput import (
        CampaignWorkflowFlightInput,
        CampaignWorkflowFlightInputTypedDict,
    )
    from .campaignworkflowroigoalinput import (
        CampaignWorkflowROIGoalInput,
        CampaignWorkflowROIGoalInputTypedDict,
    )
    from .createadgroupop import CreateAdGroupResponse, CreateAdGroupResponseTypedDict
    from .createadgroupsjobop import (
        CreateAdGroupsJobResponse,
        CreateAdGroupsJobResponseTypedDict,
    )
    from .createcampaignop import (
        CreateCampaignResponse,
        CreateCampaignResponseTypedDict,
    )
    from .createcampaignsjobop import (
        CreateCampaignsJobResponse,
        CreateCampaignsJobResponseTypedDict,
    )
    from .customcpatype import CustomCPAType
    from .customroasconfig import CustomROASConfig, CustomROASConfigTypedDict
    from .dimensionalbiddingdimensions import DimensionalBiddingDimensions
    from .enhancednielsenreportingoptions import EnhancedNielsenReportingOptions
    from .firstpartydatainput import FirstPartyDataInput, FirstPartyDataInputTypedDict
    from .getcampaignversionop import (
        GetCampaignVersionRequest,
        GetCampaignVersionRequestTypedDict,
        GetCampaignVersionResponse,
        GetCampaignVersionResponseTypedDict,
    )
    from .getfirstpartydatajobop import (
        GetFirstPartyDataJobResponse,
        GetFirstPartyDataJobResponseTypedDict,
    )
    from .getgraphqlqueryjobstatusop import (
        GetGraphQlQueryJobStatusRequest,
        GetGraphQlQueryJobStatusRequestTypedDict,
        GetGraphQlQueryJobStatusResponse,
        GetGraphQlQueryJobStatusResponseTypedDict,
    )
    from .getjobstatusop import (
        GetJobStatusRequest,
        GetJobStatusRequestTypedDict,
        GetJobStatusResponse,
        GetJobStatusResponseTypedDict,
    )
    from .getthirdpartydatajobop import (
        GetThirdPartyDataJobResponse,
        GetThirdPartyDataJobResponseTypedDict,
    )
    from .graphqljobcallbackinput import (
        GraphQlJobCallbackInput,
        GraphQlJobCallbackInputTypedDict,
    )
    from .graphqlqueryjob import GraphQlQueryJob, GraphQlQueryJobTypedDict
    from .graphqlqueryjoberror import (
        GraphQLQueryJobError,
        GraphQLQueryJobErrorTypedDict,
    )
    from .graphqlqueryjobinput import (
        GraphQlQueryJobInput,
        GraphQlQueryJobInputTypedDict,
    )
    from .graphqlqueryjobpayload import (
        GraphQlQueryJobPayload,
        GraphQlQueryJobPayloadTypedDict,
    )
    from .graphqlqueryjobresponse import (
        GraphQlQueryJobResponse,
        GraphQlQueryJobResponseTypedDict,
    )
    from .graphqlqueryjobretrievalresponse import (
        GraphQLQueryJobRetrievalResponse,
        GraphQLQueryJobRetrievalResponseTypedDict,
    )
    from .graphqlrequestinput import (
        GraphQLRequestInput,
        GraphQLRequestInputTypedDict,
        Variables,
        VariablesTypedDict,
    )
    from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
    from .keyvaluepairofstringandstringinput import (
        KeyValuePairOfStringAndStringInput,
        KeyValuePairOfStringAndStringInputTypedDict,
    )
    from .no_response_error import NoResponseError
    from .problemdetails import ProblemDetails, ProblemDetailsTypedDict
    from .problemdetails_error import ProblemDetailsError, ProblemDetailsErrorData
    from .responsevalidationerror import ResponseValidationError
    from .restapimethodtype import RestAPIMethodType
    from .security import Security, SecurityTypedDict
    from .standardjobstatusresponse import (
        StandardJobStatusResponse,
        StandardJobStatusResponseTypedDict,
    )
    from .standardjobsubmitresponse import (
        StandardJobSubmitResponse,
        StandardJobSubmitResponseTypedDict,
    )
    from .submitgraphqlqueryjobop import (
        SubmitGraphQlQueryJobResponse,
        SubmitGraphQlQueryJobResponseTypedDict,
    )
    from .submitgraphqlrequestop import (
        SubmitGraphQlRequestResponse,
        SubmitGraphQlRequestResponseTypedDict,
    )
    from .submitrestrequestop import (
        SubmitRestRequestResponse,
        SubmitRestRequestResponseBody,
        SubmitRestRequestResponseBodyTypedDict,
        SubmitRestRequestResponseTypedDict,
    )
    from .targetingendage import TargetingEndAge
    from .targetinggender import TargetingGender
    from .targetingstartage import TargetingStartAge
    from .thirdpartydatainput import ThirdPartyDataInput, ThirdPartyDataInputTypedDict
    from .updateadgroupop import UpdateAdGroupResponse, UpdateAdGroupResponseTypedDict
    from .updateadgroupsjobop import (
        UpdateAdGroupsJobResponse,
        UpdateAdGroupsJobResponseTypedDict,
    )
    from .updatecampaignop import (
        UpdateCampaignResponse,
        UpdateCampaignResponseTypedDict,
    )
    from .updatecampaignsjobop import (
        UpdateCampaignsJobResponse,
        UpdateCampaignsJobResponseTypedDict,
    )
    from .workflowcallbackinput import (
        WorkflowCallbackInput,
        WorkflowCallbackInputTypedDict,
    )
    from .workflowserror import WorkflowsError
    from .workflowstatus import WorkflowStatus

__all__ = [
    "APIError",
    "AdGroupAssociateBidList",
    "AdGroupAssociateBidListTypedDict",
    "AdGroupAudienceTargeting",
    "AdGroupAudienceTargetingTypedDict",
    "AdGroupBudget",
    "AdGroupBudgetTypedDict",
    "AdGroupBulkCreateWorkflowInputWithValidation",
    "AdGroupBulkCreateWorkflowInputWithValidationTypedDict",
    "AdGroupBulkUpdateWorkflowInputWithValidation",
    "AdGroupBulkUpdateWorkflowInputWithValidationTypedDict",
    "AdGroupChannel",
    "AdGroupComscoreSettings",
    "AdGroupComscoreSettingsTypedDict",
    "AdGroupContractTargeting",
    "AdGroupContractTargetingTypedDict",
    "AdGroupCreateWorkflowInput",
    "AdGroupCreateWorkflowInputTypedDict",
    "AdGroupCreateWorkflowInputWithValidation",
    "AdGroupCreateWorkflowInputWithValidationTypedDict",
    "AdGroupCreateWorkflowPrimaryInput",
    "AdGroupCreateWorkflowPrimaryInputTypedDict",
    "AdGroupFlight",
    "AdGroupFlightTypedDict",
    "AdGroupFunnelLocation",
    "AdGroupKoaOptimizationSettings",
    "AdGroupKoaOptimizationSettingsTypedDict",
    "AdGroupNielsenTrackingAttributes",
    "AdGroupNielsenTrackingAttributesTypedDict",
    "AdGroupPayload",
    "AdGroupPayloadTypedDict",
    "AdGroupROIGoal",
    "AdGroupROIGoalTypedDict",
    "AdGroupUpdateWorkflowInput",
    "AdGroupUpdateWorkflowInputTypedDict",
    "AdGroupUpdateWorkflowInputWithValidation",
    "AdGroupUpdateWorkflowInputWithValidationTypedDict",
    "AdGroupUpdateWorkflowPrimaryInput",
    "AdGroupUpdateWorkflowPrimaryInputTypedDict",
    "AdGroupWorkflow",
    "AdGroupWorkflowAdvancedInput",
    "AdGroupWorkflowAdvancedInputTypedDict",
    "AdGroupWorkflowAssociateBidListInput",
    "AdGroupWorkflowAssociateBidListInputTypedDict",
    "AdGroupWorkflowAudienceTargetingInput",
    "AdGroupWorkflowAudienceTargetingInputTypedDict",
    "AdGroupWorkflowBudgetInput",
    "AdGroupWorkflowBudgetInputTypedDict",
    "AdGroupWorkflowComscoreSettingsInput",
    "AdGroupWorkflowComscoreSettingsInputTypedDict",
    "AdGroupWorkflowContractTargetingInput",
    "AdGroupWorkflowContractTargetingInputTypedDict",
    "AdGroupWorkflowFlightInput",
    "AdGroupWorkflowFlightInputTypedDict",
    "AdGroupWorkflowKoaOptimizationSettingsInput",
    "AdGroupWorkflowKoaOptimizationSettingsInputTypedDict",
    "AdGroupWorkflowNewFrequencyConfigInput",
    "AdGroupWorkflowNewFrequencyConfigInputTypedDict",
    "AdGroupWorkflowNielsenTrackingAttributesInput",
    "AdGroupWorkflowNielsenTrackingAttributesInputTypedDict",
    "AdGroupWorkflowROIGoalInput",
    "AdGroupWorkflowROIGoalInputTypedDict",
    "AdGroupWorkflowTypedDict",
    "AllocationType",
    "ArchiveAdGroupsRequest",
    "ArchiveAdGroupsRequestTypedDict",
    "ArchiveAdGroupsResponse",
    "ArchiveAdGroupsResponseTypedDict",
    "ArchiveCampaignsRequest",
    "ArchiveCampaignsRequestTypedDict",
    "ArchiveCampaignsResponse",
    "ArchiveCampaignsResponseTypedDict",
    "BulkJobStatus",
    "CallRestAPIWorkflowInput",
    "CallRestAPIWorkflowInputTypedDict",
    "CampaignBulkCreateWorkflowInputWithValidation",
    "CampaignBulkCreateWorkflowInputWithValidationTypedDict",
    "CampaignBulkUpdateWorkflowInputWithValidation",
    "CampaignBulkUpdateWorkflowInputWithValidationTypedDict",
    "CampaignChannelType",
    "CampaignCreateWorkflowAdGroupAdvancedInput",
    "CampaignCreateWorkflowAdGroupAdvancedInputTypedDict",
    "CampaignCreateWorkflowAdGroupFlightInput",
    "CampaignCreateWorkflowAdGroupFlightInputTypedDict",
    "CampaignCreateWorkflowAdGroupInput",
    "CampaignCreateWorkflowAdGroupInputTypedDict",
    "CampaignCreateWorkflowInput",
    "CampaignCreateWorkflowInputTypedDict",
    "CampaignCreateWorkflowInputWithValidation",
    "CampaignCreateWorkflowInputWithValidationTypedDict",
    "CampaignCreateWorkflowPrimaryInput",
    "CampaignCreateWorkflowPrimaryInputTypedDict",
    "CampaignFlightWorkflow",
    "CampaignFlightWorkflowTypedDict",
    "CampaignPacingMode",
    "CampaignPayload",
    "CampaignPayloadTypedDict",
    "CampaignUpdateWorkflowInput",
    "CampaignUpdateWorkflowInputTypedDict",
    "CampaignUpdateWorkflowInputWithValidation",
    "CampaignUpdateWorkflowInputWithValidationTypedDict",
    "CampaignUpdateWorkflowPrimaryInput",
    "CampaignUpdateWorkflowPrimaryInputTypedDict",
    "CampaignVersionWorkflow",
    "CampaignVersionWorkflowTypedDict",
    "CampaignWorkflow",
    "CampaignWorkflowAdvancedInput",
    "CampaignWorkflowAdvancedInputTypedDict",
    "CampaignWorkflowBudgetInput",
    "CampaignWorkflowBudgetInputTypedDict",
    "CampaignWorkflowCampaignConversionReportingColumnInput",
    "CampaignWorkflowCampaignConversionReportingColumnInputTypedDict",
    "CampaignWorkflowFlightInput",
    "CampaignWorkflowFlightInputTypedDict",
    "CampaignWorkflowROIGoalInput",
    "CampaignWorkflowROIGoalInputTypedDict",
    "CampaignWorkflowTypedDict",
    "CreateAdGroupResponse",
    "CreateAdGroupResponseTypedDict",
    "CreateAdGroupsJobResponse",
    "CreateAdGroupsJobResponseTypedDict",
    "CreateCampaignResponse",
    "CreateCampaignResponseTypedDict",
    "CreateCampaignsJobResponse",
    "CreateCampaignsJobResponseTypedDict",
    "CustomCPAType",
    "CustomROASConfig",
    "CustomROASConfigTypedDict",
    "DimensionalBiddingDimensions",
    "EnhancedNielsenReportingOptions",
    "FirstPartyDataInput",
    "FirstPartyDataInputTypedDict",
    "GetCampaignVersionRequest",
    "GetCampaignVersionRequestTypedDict",
    "GetCampaignVersionResponse",
    "GetCampaignVersionResponseTypedDict",
    "GetFirstPartyDataJobResponse",
    "GetFirstPartyDataJobResponseTypedDict",
    "GetGraphQlQueryJobStatusRequest",
    "GetGraphQlQueryJobStatusRequestTypedDict",
    "GetGraphQlQueryJobStatusResponse",
    "GetGraphQlQueryJobStatusResponseTypedDict",
    "GetJobStatusRequest",
    "GetJobStatusRequestTypedDict",
    "GetJobStatusResponse",
    "GetJobStatusResponseTypedDict",
    "GetThirdPartyDataJobResponse",
    "GetThirdPartyDataJobResponseTypedDict",
    "GraphQLQueryJobError",
    "GraphQLQueryJobErrorTypedDict",
    "GraphQLQueryJobRetrievalResponse",
    "GraphQLQueryJobRetrievalResponseTypedDict",
    "GraphQLRequestInput",
    "GraphQLRequestInputTypedDict",
    "GraphQlJobCallbackInput",
    "GraphQlJobCallbackInputTypedDict",
    "GraphQlQueryJob",
    "GraphQlQueryJobInput",
    "GraphQlQueryJobInputTypedDict",
    "GraphQlQueryJobPayload",
    "GraphQlQueryJobPayloadTypedDict",
    "GraphQlQueryJobResponse",
    "GraphQlQueryJobResponseTypedDict",
    "GraphQlQueryJobTypedDict",
    "HTTPMetadata",
    "HTTPMetadataTypedDict",
    "KeyValuePairOfStringAndStringInput",
    "KeyValuePairOfStringAndStringInputTypedDict",
    "NoResponseError",
    "ProblemDetails",
    "ProblemDetailsError",
    "ProblemDetailsErrorData",
    "ProblemDetailsTypedDict",
    "ResponseValidationError",
    "RestAPIMethodType",
    "Security",
    "SecurityTypedDict",
    "StandardJobStatusResponse",
    "StandardJobStatusResponseTypedDict",
    "StandardJobSubmitResponse",
    "StandardJobSubmitResponseTypedDict",
    "SubmitGraphQlQueryJobResponse",
    "SubmitGraphQlQueryJobResponseTypedDict",
    "SubmitGraphQlRequestResponse",
    "SubmitGraphQlRequestResponseTypedDict",
    "SubmitRestRequestResponse",
    "SubmitRestRequestResponseBody",
    "SubmitRestRequestResponseBodyTypedDict",
    "SubmitRestRequestResponseTypedDict",
    "TargetingEndAge",
    "TargetingGender",
    "TargetingStartAge",
    "ThirdPartyDataInput",
    "ThirdPartyDataInputTypedDict",
    "UpdateAdGroupResponse",
    "UpdateAdGroupResponseTypedDict",
    "UpdateAdGroupsJobResponse",
    "UpdateAdGroupsJobResponseTypedDict",
    "UpdateCampaignResponse",
    "UpdateCampaignResponseTypedDict",
    "UpdateCampaignsJobResponse",
    "UpdateCampaignsJobResponseTypedDict",
    "Variables",
    "VariablesTypedDict",
    "WorkflowCallbackInput",
    "WorkflowCallbackInputTypedDict",
    "WorkflowStatus",
    "WorkflowsError",
]

_dynamic_imports: dict[str, str] = {
    "AdGroupAssociateBidList": ".adgroupassociatebidlist",
    "AdGroupAssociateBidListTypedDict": ".adgroupassociatebidlist",
    "AdGroupAudienceTargeting": ".adgroupaudiencetargeting",
    "AdGroupAudienceTargetingTypedDict": ".adgroupaudiencetargeting",
    "AdGroupBudget": ".adgroupbudget",
    "AdGroupBudgetTypedDict": ".adgroupbudget",
    "AdGroupBulkCreateWorkflowInputWithValidation": ".adgroupbulkcreateworkflowinputwithvalidation",
    "AdGroupBulkCreateWorkflowInputWithValidationTypedDict": ".adgroupbulkcreateworkflowinputwithvalidation",
    "AdGroupBulkUpdateWorkflowInputWithValidation": ".adgroupbulkupdateworkflowinputwithvalidation",
    "AdGroupBulkUpdateWorkflowInputWithValidationTypedDict": ".adgroupbulkupdateworkflowinputwithvalidation",
    "AdGroupChannel": ".adgroupchannel",
    "AdGroupComscoreSettings": ".adgroupcomscoresettings",
    "AdGroupComscoreSettingsTypedDict": ".adgroupcomscoresettings",
    "AdGroupContractTargeting": ".adgroupcontracttargeting",
    "AdGroupContractTargetingTypedDict": ".adgroupcontracttargeting",
    "AdGroupCreateWorkflowInput": ".adgroupcreateworkflowinput",
    "AdGroupCreateWorkflowInputTypedDict": ".adgroupcreateworkflowinput",
    "AdGroupCreateWorkflowInputWithValidation": ".adgroupcreateworkflowinputwithvalidation",
    "AdGroupCreateWorkflowInputWithValidationTypedDict": ".adgroupcreateworkflowinputwithvalidation",
    "AdGroupCreateWorkflowPrimaryInput": ".adgroupcreateworkflowprimaryinput",
    "AdGroupCreateWorkflowPrimaryInputTypedDict": ".adgroupcreateworkflowprimaryinput",
    "AdGroupFlight": ".adgroupflight",
    "AdGroupFlightTypedDict": ".adgroupflight",
    "AdGroupFunnelLocation": ".adgroupfunnellocation",
    "AdGroupKoaOptimizationSettings": ".adgroupkoaoptimizationsettings",
    "AdGroupKoaOptimizationSettingsTypedDict": ".adgroupkoaoptimizationsettings",
    "AdGroupNielsenTrackingAttributes": ".adgroupnielsentrackingattributes",
    "AdGroupNielsenTrackingAttributesTypedDict": ".adgroupnielsentrackingattributes",
    "AdGroupPayload": ".adgrouppayload",
    "AdGroupPayloadTypedDict": ".adgrouppayload",
    "AdGroupROIGoal": ".adgrouproigoal",
    "AdGroupROIGoalTypedDict": ".adgrouproigoal",
    "AdGroupUpdateWorkflowInput": ".adgroupupdateworkflowinput",
    "AdGroupUpdateWorkflowInputTypedDict": ".adgroupupdateworkflowinput",
    "AdGroupUpdateWorkflowInputWithValidation": ".adgroupupdateworkflowinputwithvalidation",
    "AdGroupUpdateWorkflowInputWithValidationTypedDict": ".adgroupupdateworkflowinputwithvalidation",
    "AdGroupUpdateWorkflowPrimaryInput": ".adgroupupdateworkflowprimaryinput",
    "AdGroupUpdateWorkflowPrimaryInputTypedDict": ".adgroupupdateworkflowprimaryinput",
    "AdGroupWorkflow": ".adgroupworkflow",
    "AdGroupWorkflowTypedDict": ".adgroupworkflow",
    "AdGroupWorkflowAdvancedInput": ".adgroupworkflowadvancedinput",
    "AdGroupWorkflowAdvancedInputTypedDict": ".adgroupworkflowadvancedinput",
    "AdGroupWorkflowAssociateBidListInput": ".adgroupworkflowassociatebidlistinput",
    "AdGroupWorkflowAssociateBidListInputTypedDict": ".adgroupworkflowassociatebidlistinput",
    "AdGroupWorkflowAudienceTargetingInput": ".adgroupworkflowaudiencetargetinginput",
    "AdGroupWorkflowAudienceTargetingInputTypedDict": ".adgroupworkflowaudiencetargetinginput",
    "AdGroupWorkflowBudgetInput": ".adgroupworkflowbudgetinput",
    "AdGroupWorkflowBudgetInputTypedDict": ".adgroupworkflowbudgetinput",
    "AdGroupWorkflowComscoreSettingsInput": ".adgroupworkflowcomscoresettingsinput",
    "AdGroupWorkflowComscoreSettingsInputTypedDict": ".adgroupworkflowcomscoresettingsinput",
    "AdGroupWorkflowContractTargetingInput": ".adgroupworkflowcontracttargetinginput",
    "AdGroupWorkflowContractTargetingInputTypedDict": ".adgroupworkflowcontracttargetinginput",
    "AdGroupWorkflowFlightInput": ".adgroupworkflowflightinput",
    "AdGroupWorkflowFlightInputTypedDict": ".adgroupworkflowflightinput",
    "AdGroupWorkflowKoaOptimizationSettingsInput": ".adgroupworkflowkoaoptimizationsettingsinput",
    "AdGroupWorkflowKoaOptimizationSettingsInputTypedDict": ".adgroupworkflowkoaoptimizationsettingsinput",
    "AdGroupWorkflowNewFrequencyConfigInput": ".adgroupworkflownewfrequencyconfiginput",
    "AdGroupWorkflowNewFrequencyConfigInputTypedDict": ".adgroupworkflownewfrequencyconfiginput",
    "AdGroupWorkflowNielsenTrackingAttributesInput": ".adgroupworkflownielsentrackingattributesinput",
    "AdGroupWorkflowNielsenTrackingAttributesInputTypedDict": ".adgroupworkflownielsentrackingattributesinput",
    "AdGroupWorkflowROIGoalInput": ".adgroupworkflowroigoalinput",
    "AdGroupWorkflowROIGoalInputTypedDict": ".adgroupworkflowroigoalinput",
    "AllocationType": ".allocationtype",
    "APIError": ".apierror",
    "ArchiveAdGroupsRequest": ".archiveadgroupsop",
    "ArchiveAdGroupsRequestTypedDict": ".archiveadgroupsop",
    "ArchiveAdGroupsResponse": ".archiveadgroupsop",
    "ArchiveAdGroupsResponseTypedDict": ".archiveadgroupsop",
    "ArchiveCampaignsRequest": ".archivecampaignsop",
    "ArchiveCampaignsRequestTypedDict": ".archivecampaignsop",
    "ArchiveCampaignsResponse": ".archivecampaignsop",
    "ArchiveCampaignsResponseTypedDict": ".archivecampaignsop",
    "BulkJobStatus": ".bulkjobstatus",
    "CallRestAPIWorkflowInput": ".callrestapiworkflowinput",
    "CallRestAPIWorkflowInputTypedDict": ".callrestapiworkflowinput",
    "CampaignBulkCreateWorkflowInputWithValidation": ".campaignbulkcreateworkflowinputwithvalidation",
    "CampaignBulkCreateWorkflowInputWithValidationTypedDict": ".campaignbulkcreateworkflowinputwithvalidation",
    "CampaignBulkUpdateWorkflowInputWithValidation": ".campaignbulkupdateworkflowinputwithvalidation",
    "CampaignBulkUpdateWorkflowInputWithValidationTypedDict": ".campaignbulkupdateworkflowinputwithvalidation",
    "CampaignChannelType": ".campaignchanneltype",
    "CampaignCreateWorkflowAdGroupAdvancedInput": ".campaigncreateworkflowadgroupadvancedinput",
    "CampaignCreateWorkflowAdGroupAdvancedInputTypedDict": ".campaigncreateworkflowadgroupadvancedinput",
    "CampaignCreateWorkflowAdGroupFlightInput": ".campaigncreateworkflowadgroupflightinput",
    "CampaignCreateWorkflowAdGroupFlightInputTypedDict": ".campaigncreateworkflowadgroupflightinput",
    "CampaignCreateWorkflowAdGroupInput": ".campaigncreateworkflowadgroupinput",
    "CampaignCreateWorkflowAdGroupInputTypedDict": ".campaigncreateworkflowadgroupinput",
    "CampaignCreateWorkflowInput": ".campaigncreateworkflowinput",
    "CampaignCreateWorkflowInputTypedDict": ".campaigncreateworkflowinput",
    "CampaignCreateWorkflowInputWithValidation": ".campaigncreateworkflowinputwithvalidation",
    "CampaignCreateWorkflowInputWithValidationTypedDict": ".campaigncreateworkflowinputwithvalidation",
    "CampaignCreateWorkflowPrimaryInput": ".campaigncreateworkflowprimaryinput",
    "CampaignCreateWorkflowPrimaryInputTypedDict": ".campaigncreateworkflowprimaryinput",
    "CampaignFlightWorkflow": ".campaignflightworkflow",
    "CampaignFlightWorkflowTypedDict": ".campaignflightworkflow",
    "CampaignPacingMode": ".campaignpacingmode",
    "CampaignPayload": ".campaignpayload",
    "CampaignPayloadTypedDict": ".campaignpayload",
    "CampaignUpdateWorkflowInput": ".campaignupdateworkflowinput",
    "CampaignUpdateWorkflowInputTypedDict": ".campaignupdateworkflowinput",
    "CampaignUpdateWorkflowInputWithValidation": ".campaignupdateworkflowinputwithvalidation",
    "CampaignUpdateWorkflowInputWithValidationTypedDict": ".campaignupdateworkflowinputwithvalidation",
    "CampaignUpdateWorkflowPrimaryInput": ".campaignupdateworkflowprimaryinput",
    "CampaignUpdateWorkflowPrimaryInputTypedDict": ".campaignupdateworkflowprimaryinput",
    "CampaignVersionWorkflow": ".campaignversionworkflow",
    "CampaignVersionWorkflowTypedDict": ".campaignversionworkflow",
    "CampaignWorkflow": ".campaignworkflow",
    "CampaignWorkflowTypedDict": ".campaignworkflow",
    "CampaignWorkflowAdvancedInput": ".campaignworkflowadvancedinput",
    "CampaignWorkflowAdvancedInputTypedDict": ".campaignworkflowadvancedinput",
    "CampaignWorkflowBudgetInput": ".campaignworkflowbudgetinput",
    "CampaignWorkflowBudgetInputTypedDict": ".campaignworkflowbudgetinput",
    "CampaignWorkflowCampaignConversionReportingColumnInput": ".campaignworkflowcampaignconversionreportingcolumninput",
    "CampaignWorkflowCampaignConversionReportingColumnInputTypedDict": ".campaignworkflowcampaignconversionreportingcolumninput",
    "CampaignWorkflowFlightInput": ".campaignworkflowflightinput",
    "CampaignWorkflowFlightInputTypedDict": ".campaignworkflowflightinput",
    "CampaignWorkflowROIGoalInput": ".campaignworkflowroigoalinput",
    "CampaignWorkflowROIGoalInputTypedDict": ".campaignworkflowroigoalinput",
    "CreateAdGroupResponse": ".createadgroupop",
    "CreateAdGroupResponseTypedDict": ".createadgroupop",
    "CreateAdGroupsJobResponse": ".createadgroupsjobop",
    "CreateAdGroupsJobResponseTypedDict": ".createadgroupsjobop",
    "CreateCampaignResponse": ".createcampaignop",
    "CreateCampaignResponseTypedDict": ".createcampaignop",
    "CreateCampaignsJobResponse": ".createcampaignsjobop",
    "CreateCampaignsJobResponseTypedDict": ".createcampaignsjobop",
    "CustomCPAType": ".customcpatype",
    "CustomROASConfig": ".customroasconfig",
    "CustomROASConfigTypedDict": ".customroasconfig",
    "DimensionalBiddingDimensions": ".dimensionalbiddingdimensions",
    "EnhancedNielsenReportingOptions": ".enhancednielsenreportingoptions",
    "FirstPartyDataInput": ".firstpartydatainput",
    "FirstPartyDataInputTypedDict": ".firstpartydatainput",
    "GetCampaignVersionRequest": ".getcampaignversionop",
    "GetCampaignVersionRequestTypedDict": ".getcampaignversionop",
    "GetCampaignVersionResponse": ".getcampaignversionop",
    "GetCampaignVersionResponseTypedDict": ".getcampaignversionop",
    "GetFirstPartyDataJobResponse": ".getfirstpartydatajobop",
    "GetFirstPartyDataJobResponseTypedDict": ".getfirstpartydatajobop",
    "GetGraphQlQueryJobStatusRequest": ".getgraphqlqueryjobstatusop",
    "GetGraphQlQueryJobStatusRequestTypedDict": ".getgraphqlqueryjobstatusop",
    "GetGraphQlQueryJobStatusResponse": ".getgraphqlqueryjobstatusop",
    "GetGraphQlQueryJobStatusResponseTypedDict": ".getgraphqlqueryjobstatusop",
    "GetJobStatusRequest": ".getjobstatusop",
    "GetJobStatusRequestTypedDict": ".getjobstatusop",
    "GetJobStatusResponse": ".getjobstatusop",
    "GetJobStatusResponseTypedDict": ".getjobstatusop",
    "GetThirdPartyDataJobResponse": ".getthirdpartydatajobop",
    "GetThirdPartyDataJobResponseTypedDict": ".getthirdpartydatajobop",
    "GraphQlJobCallbackInput": ".graphqljobcallbackinput",
    "GraphQlJobCallbackInputTypedDict": ".graphqljobcallbackinput",
    "GraphQlQueryJob": ".graphqlqueryjob",
    "GraphQlQueryJobTypedDict": ".graphqlqueryjob",
    "GraphQLQueryJobError": ".graphqlqueryjoberror",
    "GraphQLQueryJobErrorTypedDict": ".graphqlqueryjoberror",
    "GraphQlQueryJobInput": ".graphqlqueryjobinput",
    "GraphQlQueryJobInputTypedDict": ".graphqlqueryjobinput",
    "GraphQlQueryJobPayload": ".graphqlqueryjobpayload",
    "GraphQlQueryJobPayloadTypedDict": ".graphqlqueryjobpayload",
    "GraphQlQueryJobResponse": ".graphqlqueryjobresponse",
    "GraphQlQueryJobResponseTypedDict": ".graphqlqueryjobresponse",
    "GraphQLQueryJobRetrievalResponse": ".graphqlqueryjobretrievalresponse",
    "GraphQLQueryJobRetrievalResponseTypedDict": ".graphqlqueryjobretrievalresponse",
    "GraphQLRequestInput": ".graphqlrequestinput",
    "GraphQLRequestInputTypedDict": ".graphqlrequestinput",
    "Variables": ".graphqlrequestinput",
    "VariablesTypedDict": ".graphqlrequestinput",
    "HTTPMetadata": ".httpmetadata",
    "HTTPMetadataTypedDict": ".httpmetadata",
    "KeyValuePairOfStringAndStringInput": ".keyvaluepairofstringandstringinput",
    "KeyValuePairOfStringAndStringInputTypedDict": ".keyvaluepairofstringandstringinput",
    "NoResponseError": ".no_response_error",
    "ProblemDetails": ".problemdetails",
    "ProblemDetailsTypedDict": ".problemdetails",
    "ProblemDetailsError": ".problemdetails_error",
    "ProblemDetailsErrorData": ".problemdetails_error",
    "ResponseValidationError": ".responsevalidationerror",
    "RestAPIMethodType": ".restapimethodtype",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "StandardJobStatusResponse": ".standardjobstatusresponse",
    "StandardJobStatusResponseTypedDict": ".standardjobstatusresponse",
    "StandardJobSubmitResponse": ".standardjobsubmitresponse",
    "StandardJobSubmitResponseTypedDict": ".standardjobsubmitresponse",
    "SubmitGraphQlQueryJobResponse": ".submitgraphqlqueryjobop",
    "SubmitGraphQlQueryJobResponseTypedDict": ".submitgraphqlqueryjobop",
    "SubmitGraphQlRequestResponse": ".submitgraphqlrequestop",
    "SubmitGraphQlRequestResponseTypedDict": ".submitgraphqlrequestop",
    "SubmitRestRequestResponse": ".submitrestrequestop",
    "SubmitRestRequestResponseBody": ".submitrestrequestop",
    "SubmitRestRequestResponseBodyTypedDict": ".submitrestrequestop",
    "SubmitRestRequestResponseTypedDict": ".submitrestrequestop",
    "TargetingEndAge": ".targetingendage",
    "TargetingGender": ".targetinggender",
    "TargetingStartAge": ".targetingstartage",
    "ThirdPartyDataInput": ".thirdpartydatainput",
    "ThirdPartyDataInputTypedDict": ".thirdpartydatainput",
    "UpdateAdGroupResponse": ".updateadgroupop",
    "UpdateAdGroupResponseTypedDict": ".updateadgroupop",
    "UpdateAdGroupsJobResponse": ".updateadgroupsjobop",
    "UpdateAdGroupsJobResponseTypedDict": ".updateadgroupsjobop",
    "UpdateCampaignResponse": ".updatecampaignop",
    "UpdateCampaignResponseTypedDict": ".updatecampaignop",
    "UpdateCampaignsJobResponse": ".updatecampaignsjobop",
    "UpdateCampaignsJobResponseTypedDict": ".updatecampaignsjobop",
    "WorkflowCallbackInput": ".workflowcallbackinput",
    "WorkflowCallbackInputTypedDict": ".workflowcallbackinput",
    "WorkflowsError": ".workflowserror",
    "WorkflowStatus": ".workflowstatus",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
