"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class EnhancedNielsenReportingOptions(str, Enum):
    NONE = "None"
    AUDIENCE = "Audience"
    SITE = "Site"
