"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TargetingStartAge(str, Enum):
    TWO = "Two"
    THIRTEEN = "Thirteen"
    EIGHTEEN = "Eighteen"
    TWENTY_ONE = "TwentyOne"
    TWENTY_FIVE = "TwentyFive"
    THIRTY = "Thirty"
    THIRTY_FIVE = "ThirtyFive"
    FORTY = "Forty"
    FORTY_FIVE = "FortyFive"
    FIFTY = "Fifty"
    FIFTY_FIVE = "FiftyFive"
    SIXTY_FIVE = "SixtyFive"
