"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from ttd_workflows.types import BaseModel
from typing_extensions import Annotated, TypedDict


class AdGroupContractTargetingTypedDict(TypedDict):
    allow_open_market_bidding_when_targeting_contracts: bool


class AdGroupContractTargeting(BaseModel):
    allow_open_market_bidding_when_targeting_contracts: Annotated[
        bool, pydantic.Field(alias="allowOpenMarketBiddingWhenTargetingContracts")
    ]
