"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WorkflowStatus(str, Enum):
    IN_PROGRESS = "InProgress"
    FAILURE = "Failure"
    SUCCESS = "Success"
    PARTIAL_SUCCESS = "PartialSuccess"
    RESULTS_EXPIRED = "ResultsExpired"
