"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .adgroupworkflow import AdGroupWorkflow, AdGroupWorkflowTypedDict
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AdGroupPayloadTypedDict(TypedDict):
    ad_group: NotRequired[AdGroupWorkflowTypedDict]


class AdGroupPayload(BaseModel):
    ad_group: Annotated[Optional[AdGroupWorkflow], pydantic.Field(alias="adGroup")] = (
        None
    )
