"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DimensionalBiddingDimensions(str, Enum):
    UNKNOWN_DIMENSION = "UnknownDimension"
    HAS_AD_FORMAT_ID = "HasAdFormatId"
    HAS_DOMAIN_FRAGMENT_ID = "HasDomainFragmentId"
    HAS_UNIVERSAL_CATEGORY_TAXONOMY_ID = "HasUniversalCategoryTaxonomyId"
    HAS_PLACEMENT_POSITION_RELATIVE_TO_FOLD_ID = "HasPlacementPositionRelativeToFoldId"
    HAS_ADVERTISER_TARGETING_DATA_ID = "HasAdvertiserTargetingDataId"
    HAS_BROWSER_ID = "HasBrowserId"
    HAS_CARRIER_ID = "HasCarrierId"
    HAS_DEVICE_MODEL_ID = "HasDeviceModelId"
    HAS_DEVICE_TYPE_ID = "HasDeviceTypeId"
    HAS_GEO_SEGMENT_ID = "HasGeoSegmentId"
    HAS_HOUR_OF_WEEK = "HasHourOfWeek"
    HAS_LANGUAGE_ID = "HasLanguageId"
    HAS_OS_ID = "HasOsId"
    HAS_PRIVATE_CONTRACT_ID = "HasPrivateContractId"
    HAS_RECENCY_WINDOW_IN_MINUTES = "HasRecencyWindowInMinutes"
    HAS_RENDERING_CONTEXT_ID = "HasRenderingContextId"
    HAS_FACTUAL_GEOSTORE_TARGETING_DATA_ID = "HasFactualGeostoreTargetingDataId"
    HAS_SUPPLY_VENDOR_ID = "HasSupplyVendorId"
    HAS_TEMPERATURE_BUCKET_IN_CELSIUS = "HasTemperatureBucketInCelsius"
    HAS_THIRD_PARTY_DATA = "HasThirdPartyData"
    HAS_ADS_TXT_SELLER_TYPE_ID = "HasAdsTxtSellerTypeId"
    HAS_VIDEO_MUTED_STATE_ID = "HasVideoMutedStateId"
    HAS_VIDEO_PLAYBACK_TYPE_ID = "HasVideoPlaybackTypeId"
    HAS_VIDEO_PLAYER_SIZE_ID = "HasVideoPlayerSizeId"
    HAS_VIDEO_QUALITY_ID = "HasVideoQualityId"
    HAS_VIDEO_SKIPPABILITY_ID = "HasVideoSkippabilityId"
    HAS_FACTUAL_PROXIMITY_DATA_ID = "HasFactualProximityDataId"
    HAS_IMPRESSION_PLACEMENT_ID = "HasImpressionPlacementId"
    HAS_VIDEO_TRUTH_SCORE_RANGE = "HasVideoTruthScoreRange"
    HAS_VIDEO_VIEWABILITY_SCORE_RANGE = "HasVideoViewabilityScoreRange"
    HAS_DISPLAY_VIEWABILITY_SCORE_RANGE = "HasDisplayViewabilityScoreRange"
    HAS_PEER39_LANGUAGE_ID = "HasPeer39LanguageId"
    HAS_INTEGRAL_CONTEXTUAL_CATEGORY_ID = "HasIntegralContextualCategoryId"
    HAS_PEER39_CONTEXTUAL_CATEGORY_ID = "HasPeer39ContextualCategoryId"
    HAS_DOUBLE_VERIFY_CONTEXTUAL_CATEGORY_ID = "HasDoubleVerifyContextualCategoryId"
    HAS_INTEGRAL_BRAND_SAFETY_CATEGORY_ID = "HasIntegralBrandSafetyCategoryId"
    HAS_INTEGRAL_VIDEO_BRAND_SAFETY_CATEGORY_ID = (
        "HasIntegralVideoBrandSafetyCategoryId"
    )
    HAS_PEER39_BRAND_SAFETY_CATEGORY_ID = "HasPeer39BrandSafetyCategoryId"
    HAS_DOUBLE_VERIFY_BRAND_SAFETY_CATEGORY_ID = "HasDoubleVerifyBrandSafetyCategoryId"
    HAS_INTEGRAL_PAGE_QUALITY_CATEGORY_ID = "HasIntegralPageQualityCategoryId"
    HAS_INTEGRAL_VIDEO_PAGE_QUALITY_CATEGORY_ID = (
        "HasIntegralVideoPageQualityCategoryId"
    )
    HAS_PEER39_PAGE_QUALITY_CATEGORY_ID = "HasPeer39PageQualityCategoryId"
    HAS_DOUBLE_VERIFY_BOT_AVOIDANCE_CATEGORY_ID = (
        "HasDoubleVerifyBotAvoidanceCategoryId"
    )
    HAS_CONTEXTUAL_APP_CATEGORY_ID = "HasContextualAppCategoryId"
    HAS_PUBLISHER_ID = "HasPublisherId"
    HAS_INTEGRAL_VIEWABILITY_CATEGORY_ID = "HasIntegralViewabilityCategoryId"
    HAS_INTEGRAL_VIDEO_VIEWABILITY_CATEGORY_ID = "HasIntegralVideoViewabilityCategoryId"
    HAS_DOUBLE_VERIFY_VIEWABILITY_CATEGORY_ID = "HasDoubleVerifyViewabilityCategoryId"
    HAS_DOUBLE_VERIFY_VIDEO_VIEWABILITY_CATEGORY_ID = (
        "HasDoubleVerifyVideoViewabilityCategoryId"
    )
    HAS_FREQUENCY_ADJUSTMENT_ID = "HasFrequencyAdjustmentId"
    HAS_PEER39_VIEWABILITY_CATEGORY_ID = "HasPeer39ViewabilityCategoryId"
    HAS_VIDEO_COMPLETION_RATE_SCORE_RANGE = "HasVideoCompletionRateScoreRange"
    HAS_INTERNET_CONNECTION_TYPE_ID = "HasInternetConnectionTypeId"
    HAS_AD_BUG_PAGE_QUALITY_CATEGORY_ID = "HasAdBugPageQualityCategoryId"
    HAS_AD_BUG_VIDEO_PAGE_QUALITY_CATEGORY_ID = "HasAdBugVideoPageQualityCategoryId"
    HAS_RTB_ASIA_PAGE_QUALITY_CATEGORY_ID = "HasRTBAsiaPageQualityCategoryId"
    HAS_RTB_ASIA_VIDEO_PAGE_QUALITY_CATEGORY_ID = "HasRTBAsiaVideoPageQualityCategoryId"
    HAS_TTD_CONTEXTUAL_CATEGORY_ID = "HasTTDContextualCategoryId"
    HAS_SUPPLY_PATH_OPTIMIZATION_LIST_ID = "HasSupplyPathOptimizationListId"
    HAS_MARKET_TYPE_ID = "HasMarketTypeId"
    HAS_CONTEXTUAL_SUPPLY_VENDOR_GENRE_ID = "HasContextualSupplyVendorGenreId"
    HAS_CONTEXTUAL_SUPPLY_VENDOR_CATEGORY_ID = "HasContextualSupplyVendorCategoryId"
    HAS_WEATHER_CONDITION_ID = "HasWeatherConditionId"
    HAS_FREQUENCY_V2_ADJUSTMENT_ID = "HasFrequencyV2AdjustmentId"
    HAS_SEMASIO_CONTEXTUAL_CATEGORY_ID = "HasSemasioContextualCategoryId"
    HAS_SELLER_ID = "HasSellerId"
    HAS_DIGITAL_OUT_OF_HOME_VENUE_TYPE_ID = "HasDigitalOutOfHomeVenueTypeId"
    HAS_NATIVE_PLACEMENT_TYPE_ID = "HasNativePlacementTypeId"
    HAS_TTD_NATIVE_CONTEXT_TYPE_ID = "HasTTDNativeContextTypeId"
    HAS_DOMAIN_CLASS_ID = "HasDomainClassId"
    HAS_GEOFENCE_THIRD_PARTY_DATA_AND_BRAND = "HasGeofenceThirdPartyDataAndBrand"
    HAS_PRE_BID_CONTEXTUAL_CATEGORY_ID = "HasPreBidContextualCategoryId"
    HAS_MIAOZHEN_PAGE_QUALITY_CATEGORY_ID = "HasMiaozhenPageQualityCategoryId"
    HAS_MIAOZHEN_VIDEO_PAGE_QUALITY_CATEGORY_ID = (
        "HasMiaozhenVideoPageQualityCategoryId"
    )
    HAS_TENCENT_PAGE_QUALITY_CATEGORY_ID = "HasTencentPageQualityCategoryId"
    HAS_CONTENT_GENRE = "HasContentGenre"
    HAS_CONTENT_LIVESTREAM = "HasContentLivestream"
    HAS_CONTENT_PRODUCTION_QUALITY = "HasContentProductionQuality"
    HAS_CONTENT_RATING = "HasContentRating"
    HAS_CONTENT_DURATION = "HasContentDuration"
    HAS_TV_QUALITY_INDEX_RANGE = "HasTVQualityIndexRange"
    HAS_ATMOSPHERIC_CONDITION = "HasAtmosphericCondition"
    HAS_MARKETPLACE_ID = "HasMarketplaceId"
    HAS_AUDIENCE_REACH_PERCENTAGE_TIER_ID = "HasAudienceReachPercentageTierId"
    HAS_AD_LOAD_CATEGORY = "HasAdLoadCategory"
    HAS_FULL_REFERRER_URL = "HasFullReferrerUrl"
    HAS_LIKELY_REFRESH_RATE = "HasLikelyRefreshRate"
    HAS_CONTENT_TRANSPARENCY = "HasContentTransparency"
    HAS_IDIOSYNCRATIC_SEGMENT_ID = "HasIdiosyncraticSegmentId"
