"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CampaignChannelType(str, Enum):
    NONE = "None"
    DISPLAY = "Display"
    VIDEO = "Video"
    AUDIO = "Audio"
    TV = "TV"
    NATIVE_DISPLAY = "NativeDisplay"
    NATIVE_VIDEO = "NativeVideo"
    DOOH = "DOOH"
