"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
import pydantic
from ttd_workflows.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, TypedDict


class HTTPMetadataTypedDict(TypedDict):
    response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    request: httpx.Request
    r"""Raw HTTP request; suitable for debugging"""


class HTTPMetadata(BaseModel):
    response: Annotated[Optional[httpx.Response], pydantic.Field(exclude=True)] = None
    r"""Raw HTTP response; suitable for custom response parsing"""

    request: Annotated[Optional[httpx.Request], pydantic.Field(exclude=True)] = None
    r"""Raw HTTP request; suitable for debugging"""
