"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BulkJobStatus(str, Enum):
    QUEUED = "Queued"
    IN_PROGRESS = "InProgress"
    PARTIAL_SUCCESS = "PartialSuccess"
    FAILURE = "Failure"
    SUCCESS = "Success"
    CANCELLED = "Cancelled"
