"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomCPAType(str, Enum):
    DISABLED = "Disabled"
    PIXEL_WEIGHTING = "PixelWeighting"
    CLICK_VIEWTHROUGH_WEIGHTING = "ClickViewthroughWeighting"
