"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TargetingGender(str, Enum):
    MALE = "Male"
    FEMALE = "Female"
    BOTH = "Both"
