"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ttd_workflows.types import BaseModel
from typing_extensions import TypedDict


class StandardJobSubmitResponseTypedDict(TypedDict):
    id: int
    r"""The ID of the job."""


class StandardJobSubmitResponse(BaseModel):
    id: int
    r"""The ID of the job."""
